@@ -1,8 +1,8 @@
 from functools import wraps
 from frontegg.helpers.logger import logger
+from time import sleep
 
-
-def retry(action, total_tries=10):
+def retry(action, total_tries=10, retry_delay=0):
     def retry_decorator(f):
         @wraps(f)
         def func_with_retries(*args, **kwargs):
@@ -17,6 +17,9 @@ def retry(action, total_tries=10):
                         logger.info((action or f'function "{f.__name__}"') + f' failed on the last retry attempt ({total_tries}), {e}')
                         raise e
                     _tries += 1
+                    if retry_delay > 0:
+                        sleep(retry_delay)
+
 
         return func_with_retries
 
